@@ -416,7 +416,7 @@ class Hustle(object):
             if not group_id and 'group_id' not in table.columns:
                 raise ValueError('Group Id must be passed as an argument or a column value.')
             if group_id:
-                lead['group_id'] == group_id
+                lead['group_id'] = group_id
 
             created_leads.append(self.create_lead(**lead))
 
@@ -443,6 +443,8 @@ class Hustle(object):
                 The notes for the lead
             follow_up: str
                 Follow up for the lead
+            tag_ids: list
+                Tags to apply to lead
         `Returns:`
             dict
         """
@@ -459,7 +461,7 @@ class Hustle(object):
         # Remove empty args in dictionary
         lead = json_format.remove_empty_keys(lead)
 
-        logger.info('Updating lead for {first_name} {last_name}.')
+        logger.info(f'Updating lead for {first_name} {last_name}.')
         return self._request(f'leads/{lead_id}', req_type="PUT", payload=lead)
 
     def get_tags(self, organization_id):
